#highlight-str

[![travis](https://img.shields.io/travis/mawni/highlight-str/master.svg)](https://travis-ci.org/mawni/highlight-str) [![npm](https://img.shields.io/npm/v/highlight-str.svg?maxAge=2592000?style=flat-square)](https://npmjs.org/package/highlight-str)

`highlight-str` is a tiny [node](https://nodejs.org) module that highlights a specific string or an array of strings in another string using the given highlight color and returns a callback function with either an error or the transformed string with highlighted terms. The `highlight_color` can be any of [chalk colors](https://github.com/chalk/chalk#colors).

###install

`npm install highlight-str`

###api

**highlight(str, hl_term, hl_color, callback)**

+ `str` {String} -- the base string
+ `hl_term` {String}|{Array} -- string tokens to be highlighted; it can be a string or an array of strings
+ `hl_color` {String}|{Array} -- any [chalk colors](https://github.com/chalk/chalk#colors); color name can be a string or an array of strings
+ `callback` {Function} -- gets two arguments (err, highlighted_str)
  + `err` is an Error object (you get the error message by err.message)
  + `highlighted_str` is the `str` with highlighted terms

when `hl_term` is a string, the `hl_color` must be a string too. But, when `hl_term` is an array of strings, the `hl_color` can be a string or an array of strings. For the cases where they are both an array, then `hl_term` will directly be mapped to `hl_color`. In other words, `hl_term[0]` will be mapped to `hl_color[0]` and so on. (see example below)

###example

*highlight a string*

```javascript

const hl = require('highlight-str');

var str = 'The quick brown fox jumps over the lazy dog';
// highlight one string
var word = 'fox';
var hl_color = 'green';

hl(str, word, hl_color, (err, result) => {
  if (err) {
    console.error(err.message);
  } else {
    console.log(result);
  }
});
```
*highlight an array of strings with a single color*

```javascript
const hl = require('highlight-str');

var str = 'The quick brown fox jumps over the lazy dog';
// highlight array of strings
var words = ['quick', 'fox', 'lazy dog'];

hl(str, words, 'yellow', (err, result) => {
  if (err) {
    console.error(err.message); 
  } else {
    console.log(result); 
  }
});
```

*highlight an array of strings with an array of colors (direct map)*

```javascript
const hl = require('highlight-str');

var str = 'The quick brown fox jumps over the lazy dog';
// highlight array of strings
var words = ['quick', 'fox', 'dog'];
var colors = ['gray', 'magenta', 'red'];

// in result,
//  quick will be gray
//  fox will be magenta
//  dog will be red

hl(str, words, colors, (err, result) => {
  if (err) {
    console.error(err.message); 
  } else {
    console.log(result); 
  }
});
```

